'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (text) {
  return new Promise((resolve, reject) => {
    tagger.tag(text, (err, results) => {
      if (err) {
        reject(err);
        return;
      }

      const sentence = results.map((parsed, i) => {
        // Get a context around the processing word.
        const getPart = () => (results[i - 1] ? results[i - 1].t : '') + ' ' + parsed.t + ' ' + (results[i + 1] ? results[i + 1].t : '');

        let shouldSpaced = true;
        let lemma;

        // Warn if an extra period is inserted
        // because it will affect the sentence separation process.
        if (!parsed.t.includes('.') && parsed.l.includes('.')) {
          console.warn('"." is added!:', getPart());
        }

        // A word TreeTagger failed to determine the lemma is usually
        // a proper noun. But sometimes inappropriate unicode characters
        // are also reported as <unknown>, which should be removed.
        if (parsed.l === '<unknown>') {
          const isSign = /^\W+$/.test(parsed.t);

          if (isSign) {
            console.log(parsed, `sign: ${ isSign }, part: ${ getPart() }`);
            lemma = '';
          } else {
            lemma = parsed.t;
          }
        } else {
          switch (parsed.pos) {
            case 'CD':
              // cardinal numbers have no lemma.
              // (TreeTagger put '@CARD@' as a lemma of CD)
              lemma = parsed.t;
              break;

            case 'PP':
              // Replace personal pronouns with abstract ones.
              if (/sel(?:f|ves)$/.test(parsed.t)) {
                lemma = 'oneself';
              } else {
                lemma = 'one';
              }
              break;

            case 'PP$':
              // Replace possessive pronoun with abstract one.
              lemma = 'one\'s';
              break;

            case 'POS':
              // Always use "'s" even for plural nouns
              // to enable QuizGenerator process easily.
              lemma = '\'s';
              shouldSpaced = false;
              break;

            default:
              if (results[i + 1] && results[i + 1].pos === 'POS') {
                // Replace all possessive proper nouns with "one's".
                lemma = 'one';
              } else if (parsed.t.includes('\'')) {
                // If the input word have an apostrophe (e.g. 'm as in I'm),
                // make sure the lemma also have an apostrophe
                // and doesn't spaced between the previous word
                // so that a word count will not be differed
                // among a source and lemmatized texts.
                lemma = '\'' + parsed.l;
                shouldSpaced = false;
              } else {
                lemma = parsed.l || parsed.t;
              }
              break;
          }
        }

        return shouldSpaced ? ` ${ lemma }` : lemma;
      }).join('');

      resolve(sentence);
    });
  });
};

var _treetagger = require('treetagger');

var _treetagger2 = _interopRequireDefault(_treetagger);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// This env. variable will be used by treetagger package.
/**
 * Lemmatizer for English using TreeTagger
 */
process.env.TREETAGGER_HOME = _path2.default.join(__dirname, '..', '..', 'vendor', 'treetagger', 'cmd');

const tagger = new _treetagger2.default();
//# sourceMappingURL=english.js.map